From: Arnaud Giersch <arnaud.giersch@iut-bm.univ-fcomte.fr>
Date: Tue, 25 Jan 2011 09:14:22 +0000 (+0100)
Subject: Rename process::send() -> process::send_all().
X-Git-Tag: v0.1~188^2~17
X-Git-Url: https://bilbo.iut-bm.univ-fcomte.fr/and/gitweb/loba.git/commitdiff_plain/ea9e469b934dd81706ec3f727156b9057e4cf2bb?ds=sidebyside;hp=825abbb3bde6c35ab1d1cdfba25fba4be5dcea2f

Rename process::send() -> process::send_all().
---

diff --git a/process.h b/process.h
index fb1fe3f..a197e9a 100644
--- a/process.h
+++ b/process.h
@@ -94,7 +94,7 @@ private:
     // Send procedures, with helpers for bookkeeping mode or not
     void send1_no_bookkeeping(neighbor& nb);
     void send1_bookkeeping(neighbor& nb);
-    void send();
+    void send_all();
 
     // Returns true if there remains neighbors to listen for
     bool may_receive() { return ctrl_close_pending || data_close_pending; }
diff --git a/process.cpp b/process.cpp
index acd7aed..a0447de 100644
--- a/process.cpp
+++ b/process.cpp
@@ -36,7 +36,7 @@ process::process(int argc, char* argv[])
 
     comp = 0.0;
 
-    prev_load_broadcast = -1;   // force sending of load on first send()
+    prev_load_broadcast = -1;   // force sending of load on first send_all()
     expected_load = load;
     total_load_running += load;
     total_load_init += load;
@@ -109,7 +109,7 @@ int process::run()
         lb_load() = ld;
 
         // send load information, and load (data) if any
-        send();
+        send_all();
         if (load > 0.0) {
             ++comp_iter;
             compute();
@@ -248,7 +248,7 @@ void process::send1_bookkeeping(neighbor& nb)
         comm.send(nb.get_data_mbox(), new message(message::LOAD, load_to_send));
 }
 
-void process::send()
+void process::send_all()
 {
     using std::tr1::bind;
     using std::tr1::placeholders::_1;